Struct NonStandardSighashTypeError
pub struct NonStandardSighashTypeError(pub u32);Expand description
This type is consensus valid but an input including it would prevent the transaction from being relayed on today’s Bitcoin network.
Tuple Fields
0: u32Trait Implementations
impl Clone for NonStandardSighashTypeError
impl Clone for NonStandardSighashTypeError
fn clone(&self) -> NonStandardSighashTypeError
fn clone(&self) -> NonStandardSighashTypeError
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for NonStandardSighashTypeError
impl Debug for NonStandardSighashTypeError
impl Display for NonStandardSighashTypeError
impl Display for NonStandardSighashTypeError
impl Error for NonStandardSighashTypeError
Available on crate feature std only.
impl Error for NonStandardSighashTypeError
Available on crate feature
std only.fn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
impl From<NonStandardSighashTypeError> for Error
impl From<NonStandardSighashTypeError> for Error
fn from(e: NonStandardSighashTypeError) -> Error
fn from(e: NonStandardSighashTypeError) -> Error
Converts to this type from the input type.
impl PartialEq for NonStandardSighashTypeError
impl PartialEq for NonStandardSighashTypeError
impl Eq for NonStandardSighashTypeError
impl StructuralPartialEq for NonStandardSighashTypeError